import numpy as np
import glob

class postproc():

    # Constructor for class, designed for particular folder,
    # header name and file type
    def __init__(self, foldername, headername, basename):

        self.foldername = foldername
        self.headername = headername
        self.basename = basename
        self.header = self.read_header(foldername+headername)
        self.files = self.get_files(foldername, basename)

    #Read header data
    def read_header(self, headername):
        header = {}
        f = open(headername)
        for l in f.readlines():
            key, value = l.split()
            #Reading mixed int/float, try and ask forgiveness...
            try:
                header[key] = int(value)
            except ValueError: 
                header[key] = float(value)
        return header

    #Read files in folder
    def get_files(self, foldername, basename):
        files = glob.glob(foldername + basename + "*")
        files.sort()
        return files

    def get_Nrecs(self):
        return len(self.files)

    #Read file number
    def read_file(self, filename):
        return np.fromfile(open(filename,'rb'), dtype='d')

    def read_field(self, recno):
        if recno > self.get_Nrecs():
            raise IndexError("Error request record is greater than"
                             + " max record no. " +  str(self.get_Nrecs()))
        data = self.read_file(self.files[recno])
        field = data.reshape(self.header['Nx'],
                             self.header['Nz'])

        return field.T
